@@ -85,6 +85,7 @@ class ControllerAPI:
                     for response in responses_json['async-responses']:
                         if response['id'] == req_id:
                             pelion_command_response = {}
+                            pelion_command_response['status_code'] = 200 #default is OK... we refine below...
                             if 'status' in response:
                                 pelion_command_response['status_code'] = response['status']
                             if 'payload' in response:
@@ -145,7 +146,7 @@ class ControllerAPI:
         if result['status_code'] >= 200 and result['status_code'] < 300:
             return self.pelion_get_config()
         else:
-            print("PelionSageAPI (PUT) set_config FAILED with status: " + str(result.status_code))
+            print("PelionSageAPI (PUT) set_config FAILED with status: " + str(result['status_code']))
             return result
 
     #
@@ -282,7 +283,7 @@ class MyNotebook:
             print(self.pelion_api.pelion_get_config())
         else:
             print("")
-            print("Configuration Sync FAILED with code: " + str(result.status_code))
+            print("Configuration Sync FAILED with code: " + str(result['status_code']))
             print("Please confirm Edge Agent PT DeviceID and Edge gateway availability and retry...")
             
     # Save off the model
